function [ results ] = run_experiment( s, seed )

% set the random seed
rng(seed);

% compute the optimal allocation
lambda_star = compute_allocation(s.w, s.MAB.mu, s.MAB.var, s.MAB.K);
f_star = objective_fun(s.w, s.MAB.mu, s.MAB.var, lambda_star, s.MAB.K);

% execute one simulation
disp(['======================== Experiment ' s.idx ' =======================']);
disp(['Mean     : ' num2str(s.MAB.mu')]);
disp(['Variance : ' num2str(s.MAB.var')]);
disp(['Optimal allocation : ' num2str(lambda_star')]);
disp(['Optimal value      : ' num2str(f_star)]);
disp(['Steps : ' num2str(s.n)]);
disp(['Alg : ' num2str(s.alg.id)]);
disp(['Alg-parameters : ']);
disp(s.alg.params);

tic;
[lambda_hat, lambda_tilde, mu_hat, var_hat, pulls] = run_alg(s);
toc;

disp(['Est. Mean     : ' num2str(mu_hat')]);
disp(['Est. Variance : ' num2str(var_hat')]);
disp(['Est. opt. allocation : ' num2str(lambda_hat(:,s.n)')]);
disp(['Realized  allocation : ' num2str(lambda_tilde(:,s.n)')]);

% compute the performance of the realized allocation
f_tilde = objective_fun(s.w,s.MAB.mu,s.MAB.var,lambda_tilde(:,s.n),s.MAB.K);
disp(['Value : ' num2str(f_tilde)]);

% compute the corresponding pseudo regret
regret = f_star - f_tilde;
disp(['Regret : ' num2str(regret)]);

% compute the continuous pseudo regret over time
cont_f_tilde = zeros(s.n, 1);
for t=1:s.n
    cont_f_tilde(t) = objective_fun(s.w,s.MAB.mu,s.MAB.var,lambda_tilde(:,t),s.MAB.K);
end
cont_regret = f_star - cont_f_tilde;

% store all the results in a structure
results.seed = seed;
results.setting = s;
results.lambda_star = lambda_star;
results.f_star = f_star;
results.lambda_hat = lambda_hat;
results.lambda_tilde = lambda_tilde;
results.f_tilde = f_tilde;
results.mu_hat = mu_hat;
results.var_hat = var_hat;
results.pulls = pulls;
results.regret = regret;
results.cont_regret = cont_regret;
