function [ lambda_hat, lambda_tilde, mu_hat, var_hat, pulls ] = run_alg( s )

%% setup
K = s.MAB.K;

lambda_hat   = zeros(K, s.n);
lambda_tilde = zeros(K, s.n);

%% arms estimates and parameters for UCB-like algorithms
m1_hat = zeros(K,1);
m2_hat = zeros(K,1);
mu_hat = zeros(K,1);
var_hat = zeros(K,1);
pulls = zeros(K,1);

UCB_mu = zeros(K,1);
UCB_var = zeros(K,1);
UCBV_mu = zeros(K,1);
UCBV_var = zeros(K,1);

%% pull each arm twice
for i=1:K
    sample1 = s.MAB.arms(i).play;
    sample2 = s.MAB.arms(i).play;
    
    m1_hat(i) = sample1+sample2;
    m2_hat(i) = sample1^2+sample2^2;
    mu_hat(i) = m1_hat(i)/2;
    var_hat(i) = m2_hat(i)/2-mu_hat(i)^2;
    
    pulls(i) = 2;
end

lambda_tilde(:,2*K) = pulls./(2*K);

%% pull arms until the end of the experiment
for t=2*K+1:s.n
    
    if (strcmp(s.alg.id,'UCB'))
        % compute upper confidence bounds for both mean and variance
        UCB_mu  = mu_hat  + s.alg.params.rho_mu * sqrt(log(s.n)./pulls);
        UCB_var = var_hat + s.alg.params.rho_var* sqrt(log(s.n)./pulls);
        
        % estimated optimal allocation
        lambda_hat(:,t) = compute_allocation(s.w, UCB_mu, UCB_var, K);
        
        % compute the extent to which each arm is underpulled
        lambda_diff = lambda_hat(:,t) - lambda_tilde(:,t-1);
        
        [~,arm_to_pull] = max(lambda_diff);

    elseif (strcmp(s.alg.id,'UCB-Rand'))
        % compute upper confidence bounds for both mean and variance
        UCB_mu  = mu_hat  + s.alg.params.rho_mu * sqrt(log(s.n)./pulls);
        UCB_var = var_hat + s.alg.params.rho_var* sqrt(log(s.n)./pulls);
        
        % estimated optimal allocation
        lambda_hat(:,t) = compute_allocation(s.w, UCB_mu, UCB_var, K);
        
        % pull an arm at random wrt the estimated optimal allocation
        arm_to_pull = find( mnrnd(1, lambda_hat(:,t)) == 1);
        
    elseif (strcmp(s.alg.id,'UCBV'))
        % compute upper confidence bounds for both mean and variance
        UCBV_mu  = mu_hat  + sqrt(log(s.n)*var_hat./pulls) + s.alg.params.rho_mu*log(s.n)./pulls;
        UCBV_var = var_hat + sqrt(log(s.n)*var_hat./pulls) + s.alg.params.rho_var*log(s.n)./pulls;
        
        % estimated optimal allocation
        lambda_hat(:,t) = compute_allocation(s.w, UCBV_mu, UCBV_var, K);
        
        % compute the extent to which each arm is underpulled
        lambda_diff = lambda_hat(:,t) - lambda_tilde(:,t-1);
        
        [~,arm_to_pull] = max(lambda_diff);

    elseif (strcmp(s.alg.id,'ExplorExploit'))
        
        if (t < s.alg.params.tau)
            [~, arm_to_pull] = min(pulls);
        elseif (t == s.alg.params.tau)
            lambda_hat(:,t) = compute_allocation(s.w, mu_hat, var_hat, K);
            [~, arm_to_pull] = min(pulls);
        else
            lambda_hat(:,t) = lambda_hat(:,t-1);
            % compute the extent to which each arm is underpulled
            lambda_diff = lambda_hat(:,t) - lambda_tilde(:,t-1);
            [~,arm_to_pull] = max(lambda_diff);
        end 
        
    elseif (strcmp(s.alg.id,'EpsGreedy'))
        if (rand > s.alg.params.eps)
            % estimated optimal allocation
            lambda_hat(:,t) = compute_allocation(s.w, mu_hat, var_hat, K);
        
            % pull an arm at random wrt the estimated optimal allocation
            arm_to_pull = find( mnrnd(1, lambda_hat(:,t)) == 1);
        else
            % pull an arm at random
            arm_to_pull = unidrnd(K);
        end
        
    end

    
    sample = s.MAB.arms(arm_to_pull).play;
    
    if (strcmp(s.alg.id,'UCB') || strcmp(s.alg.id,'UCB-Rand') || strcmp(s.alg.id,'UCBV') || strcmp(s.alg.id,'ExplorExploit') || strcmp(s.alg.id,'EpsGreedy'))
        
        m1_hat(arm_to_pull) = m1_hat(arm_to_pull)+sample;
        m2_hat(arm_to_pull) = m2_hat(arm_to_pull)+sample^2;
        pulls(arm_to_pull) = pulls(arm_to_pull)+1;
        
        mu_hat(arm_to_pull) = m1_hat(arm_to_pull)/pulls(arm_to_pull);
        var_hat(arm_to_pull) = m2_hat(arm_to_pull)/pulls(arm_to_pull)-mu_hat(arm_to_pull)^2;
    end
    
    lambda_tilde(:,t) = pulls./t;
end

end

